==> ZUtil-1.8.0-sources.jar: top/zhogjianhao/date/constant/DatePattern.java <==
package top.zhogjianhao.date.constant;

/**
 * 时间格式
 */
public class DatePattern {

  public static final String UUUU_MM_DD_HH_MM_SS = "uuuu-MM-dd HH:mm:ss";
  public static final String UUUU_MM_DD_SLASH_HH_MM_SS = "uuuu/MM/dd HH:mm:ss";
  public static final String UUUU_MM_DD_DOT_HH_MM_SS = "uuuu.MM.dd HH:mm:ss";
  public static final String UUUUMMDDHHMMSS = "uuuuMMddHHmmss";
  public static final String UUUU_MM_DD_HH_MM = "uuuu-MM-dd HH:mm";
  public static final String UUUU_MM_DD_SLASH_HH_MM = "uuuu/MM/dd HH:mm";
  public static final String UUUU_MM_DD_DOT_HH_MM = "uuuu.MM.dd HH:mm";
  public static final String UUUU_MM_DD = "uuuu-MM-dd";
  public static final String UUUU_MM_DD_SLASH = "uuuu/MM/dd";
  public static final String UUUU_MM_DD_DOT = "uuuu.MM.dd";
  public static final String UUUU_MM = "uuuu-MM";
  public static final String UUUU_MM_SLASH = "uuuu/MM";
  public static final String UUUU_MM_DOT= "uuuu.MM";

  public static final String YYYY_MM_DD_HH_MM_SS = "yyyy-MM-dd HH:mm:ss";
  public static final String YYYY_MM_DD_SLASH_HH_MM_SS = "yyyy/MM/dd HH:mm:ss";
  public static final String YYYY_MM_DD_DOT_HH_MM_SS = "yyyy.MM.dd HH:mm:ss";
  public static final String YYYYMMDDHHMMSS = "yyyyMMddHHmmss";
  public static final String YYYY_MM_DD_HH_MM = "yyyy-MM-dd HH:mm";
  public static final String YYYY_MM_DD_SLASH_HH_MM = "yyyy/MM/dd HH:mm";
  public static final String YYYY_MM_DD_DOT_HH_MM = "yyyy.MM.dd HH:mm";
  public static final String YYYY_MM_DD = "yyyy-MM-dd";
  public static final String YYYY_MM_DD_SLASH = "yyyy/MM/dd";
  public static final String YYYY_MM_DD_DOT = "yyyy.MM.dd";
  public static final String YYYY_MM = "yyyy-MM";
  public static final String YYYY_MM_SLASH = "yyyy/MM";
  public static final String YYYY_MM_DOT = "yyyy.MM";

  public static final String MM_DD_HH_MM_SS = "MM-dd HH:mm:ss";
  public static final String MM_DD_SLASH_HH_MM_SS = "MM/dd HH:mm:ss";
  public static final String MM_DD_DOT_HH_MM_SS = "MM.dd HH:mm:ss";
  public static final String MMDDHHMMSS = "MMddHHmmss";
  public static final String MM_DD_HH_MM = "MM-dd HH:mm";
  public static final String MM_DD_SLASH_HH_MM = "MM/dd HH:mm";
  public static final String MM_DD_DOT_HH_MM = "MM.dd HH:mm";
  public static final String MM_DD = "MM-dd";
  public static final String MM_DD_SLASH = "MM/dd";
  public static final String MM_DD_DOT = "MM.dd";
  public static final String HH_MM_SS = "HH:mm:ss";
  public static final String HH_MM = "HH:mm";
}

==> ZUtil-1.8.2-sources.jar: top/zhogjianhao/date/constant/DatePattern.java <==
package top.zhogjianhao.date.constant;

import java.time.format.DateTimeFormatterBuilder;

/**
 * 时间格式
 *
 * 参考 {@link DateTimeFormatterBuilder#appendPattern(String)}
 */
public class DatePattern {

  public static final String UUUU_MM_DD_HH_MM_SS = "uuuu-MM-dd HH:mm:ss";
  public static final String UUUU_MM_DD_SLASH_HH_MM_SS = "uuuu/MM/dd HH:mm:ss";
  public static final String UUUU_MM_DD_DOT_HH_MM_SS = "uuuu.MM.dd HH:mm:ss";
  public static final String UUUUMMDDHHMMSS = "uuuuMMddHHmmss";
  public static final String UUUU_MM_DD_HH_MM = "uuuu-MM-dd HH:mm";
  public static final String UUUU_MM_DD_SLASH_HH_MM = "uuuu/MM/dd HH:mm";
  public static final String UUUU_MM_DD_DOT_HH_MM = "uuuu.MM.dd HH:mm";
  public static final String UUUU_MM_DD = "uuuu-MM-dd";
  public static final String UUUU_MM_DD_SLASH = "uuuu/MM/dd";
  public static final String UUUU_MM_DD_DOT = "uuuu.MM.dd";
  public static final String UUUU_MM = "uuuu-MM";
  public static final String UUUU_MM_SLASH = "uuuu/MM";
  public static final String UUUU_MM_DOT= "uuuu.MM";

  public static final String YYYY_MM_DD_HH_MM_SS = "yyyy-MM-dd HH:mm:ss";
  public static final String YYYY_MM_DD_SLASH_HH_MM_SS = "yyyy/MM/dd HH:mm:ss";
  public static final String YYYY_MM_DD_DOT_HH_MM_SS = "yyyy.MM.dd HH:mm:ss";
  public static final String YYYYMMDDHHMMSS = "yyyyMMddHHmmss";
  public static final String YYYY_MM_DD_HH_MM = "yyyy-MM-dd HH:mm";
  public static final String YYYY_MM_DD_SLASH_HH_MM = "yyyy/MM/dd HH:mm";
  public static final String YYYY_MM_DD_DOT_HH_MM = "yyyy.MM.dd HH:mm";
  public static final String YYYY_MM_DD = "yyyy-MM-dd";
  public static final String YYYY_MM_DD_SLASH = "yyyy/MM/dd";
  public static final String YYYY_MM_DD_DOT = "yyyy.MM.dd";
  public static final String YYYY_MM = "yyyy-MM";
  public static final String YYYY_MM_SLASH = "yyyy/MM";
  public static final String YYYY_MM_DOT = "yyyy.MM";

  public static final String MM_DD_HH_MM_SS = "MM-dd HH:mm:ss";
  public static final String MM_DD_SLASH_HH_MM_SS = "MM/dd HH:mm:ss";
  public static final String MM_DD_DOT_HH_MM_SS = "MM.dd HH:mm:ss";
  public static final String MMDDHHMMSS = "MMddHHmmss";
  public static final String MM_DD_HH_MM = "MM-dd HH:mm";
  public static final String MM_DD_SLASH_HH_MM = "MM/dd HH:mm";
  public static final String MM_DD_DOT_HH_MM = "MM.dd HH:mm";
  public static final String MM_DD = "MM-dd";
  public static final String MM_DD_SLASH = "MM/dd";
  public static final String MM_DD_DOT = "MM.dd";
  public static final String HH_MM_SS = "HH:mm:ss";
  public static final String HH_MM = "HH:mm";
}
